==> sciqlopplots-0.11.0.tar.gz: sciqlopplots-0.11.0/include/SciQLopPlots/Inspector/PropertiesDelegates/SciQLopPlotAxisDelegate.hpp <==
/*------------------------------------------------------------------------------
-- This file is a part of the SciQLop Software
-- Copyright (C) 2024, Plasma Physics Laboratory - CNRS
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-------------------------------------------------------------------------------*/
/*-- Author : Alexis Jeandet
-- Mail : alexis.jeandet@member.fsf.org
----------------------------------------------------------------------------*/
#pragma once
#include "SciQLopPlots/Inspector/PropertyDelegateBase.hpp"

class SciQLopPlotAxisInterface;

class SciQLopPlotAxisDelegate : public PropertyDelegateBase
{
    Q_OBJECT

    SciQLopPlotAxisInterface* plot() const;


public:
    using compatible_type = SciQLopPlotAxisInterface;
    SciQLopPlotAxisDelegate(SciQLopPlotAxisInterface* object, QWidget* parent = nullptr);

    virtual ~SciQLopPlotAxisDelegate() = default;
};

==> sciqlopplots-0.15.0.tar.gz: sciqlopplots-0.15.0/include/SciQLopPlots/Inspector/PropertiesDelegates/SciQLopPlotAxisDelegate.hpp <==
/*------------------------------------------------------------------------------
-- This file is a part of the SciQLop Software
-- Copyright (C) 2024, Plasma Physics Laboratory - CNRS
--
-- This program is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-------------------------------------------------------------------------------*/
/*-- Author : Alexis Jeandet
-- Mail : alexis.jeandet@member.fsf.org
----------------------------------------------------------------------------*/
#pragma once
#include "SciQLopPlots/Inspector/PropertyDelegateBase.hpp"

class SciQLopPlotAxisInterface;
class SciQLopPlotColorScaleAxis;

class SciQLopPlotAxisDelegate : public PropertyDelegateBase
{
    Q_OBJECT

    SciQLopPlotAxisInterface* axis() const;
    SciQLopPlotColorScaleAxis* color_scale() const;

    void addWidgetWithLabel(QWidget* widget, const QString& label);

public:
    using compatible_type = SciQLopPlotAxisInterface;
    SciQLopPlotAxisDelegate(SciQLopPlotAxisInterface* object, QWidget* parent = nullptr);

    virtual ~SciQLopPlotAxisDelegate() = default;
};
